#' ---
#' author: "Pablo Diego-Rosell, PhD"
#' email: "pablo_diego_rosell@yahoo.com"
#' output:
#'    html_document:
#'      toc: true
#' theme: united
#' ---

rm(list=ls(all=t))

#'# Setup filenames

filename <- "ECE 2016 (B1)" # !!!Update filename

if (!require("pacman")) install.packages("pacman")
pacman::p_load(rio)
rio::convert(paste0(filename, ".xlsx"), paste0(filename, ".dta"))

functions_vers <-  "functions_1.7.R" # !!!Update helper functions file

#'# Setup data, functions and create dictionary for dataset review
source (functions_vers)

# Label vars

var_label(mydata$cod_mod7) <-"Codigo modular de la IE (Muestra DFM)"
var_label(mydata$anexo) <-"Anexo de la IE (Muestra DFM)"
var_label(mydata$grado) <-"Grado de la IE (Muestra DFM)"
var_label(mydata$dni) <-"Dni del estudiante (Muestra DFM)"
var_label(mydata$nombres) <-"Nombres del estudiante (Muestra DFM)"
var_label(mydata$apellido_paterno) <-"Apellido paterno del estudiante (Muestra DFM)"
var_label(mydata$apellido_materno) <-"Apellido materno del estudiante (Muestra DFM)"
var_label(mydata$ID_seccion_ece16) <-"ID de la Seccion(Aula) donde el estudiante fue evaluado en la ECE 2016"
var_label(mydata$cor_est_ece16) <-"Correlativo del estudiante cuando fue evaluado en la ECE 2016"
var_label(mydata$paterno_ece16) <-"Apellido paterno del estudiante en la ECE 2016"
var_label(mydata$materno_ece16) <-"Apellido materno del estudiante en la ECE 2016"
var_label(mydata$nombre1_ece16) <-"Primer nombre del estudiante en la ECE 2016"
var_label(mydata$nombre2_ece16) <-"Segundo nombre del estudiante en la ECE 2016"
var_label(mydata$M500_L_ece16) <-"Medida Promedio en Comprension Lectora del estudiante en la ECE2016"
var_label(mydata$M500_M_ece16) <-"Medida Promedio en Matematica del estudiante en la ECE2016"
var_label(mydata$M500_H_ece16) <-"Medida Promedio en Historia, Geografia y Economia del estudiante en la ECE2016"
var_label(mydata$grupo_L_ece16) <-"Nivel de desempeno en Comprension Lectora del estudiante en la ECE2016"
var_label(mydata$grupo_M_ece16) <-"Nivel de desempeno en Matematica del estudiante en la ECE2016"
var_label(mydata$grupo_HGE_ece16) <-"Nivel de desempeno en Historia, Geografia y Economia del estudiante en la ECE2016"

#' Visually inspect variables in "dictionary.csv" and flag for risk, using the following flags: 
# Direct PII: Respondent Names, Addresses, Identification Numbers, Phone Numbers
# Direct PII-team: Interviewer Names, other field team names 
# Indirect PII-ordinal: Date of birth, Age, income, education, household composition. 
# Indirect PII-categorical: Gender, education, ethnicity, nationality,
# occupation, employer, head of household, marital status
# GPS: Longitude, Latitude
# Small Location: Location (<100,000) 
# Large Location (>100,000)
# Weight: weightVar
# Household ID:  hhId, 
# Open-ends: Review responses for any sensitive information, redact as necessary 


#'# Direct PII: variables to be removed

# !!!Include any Direct PII variables
dropvars <- c("dni",
              "nombres",
              "apellido_paterno",
              "apellido_materno",
              "paterno_ece16",
              "materno_ece16",
              "nombre1_ece16",
              "nombre2_ece16") 
mydata <- mydata[!names(mydata) %in% dropvars]

#'# Direct PII-team: Encode field team names
# !!!No Direct PII - team


#'# Small locations: Encode locations  with pop <100,000 using random large numbers
# !!!Include relevant variables, but check their population size first to confirm they are <100,000

locvars <- c("cod_mod7") 
mydata <- encode_location (variables= locvars, missing=999999)

#'# Indirect PII - Ordinal: Global recode or Top/bottom coding for extreme values
# !!!No Indirect PII - Ordinal


#'# Indirect PII - Categorical: Recode, encode, or Top/bottom coding for extreme values
# !!!No Indirect PII - Categorical


#'# Matching and crosstabulations: Run automated PII check 
# !!!Insufficient demographic data


#'# Open-ends: review responses for any sensitive information, redact as necessary
# !!!No Open-ends


#'# GPS data: Displace
# !!!No GPS data


#'# Save processed data in Stata and SPSS format

range <- 1:length(names(mydata))

for (i in range){
  names(mydata)[i]=gsub("[[:punct:]]", "", names(mydata)[i])
}


haven::write_dta(mydata, paste0(filename, "_PU.dta"))
haven::write_sav(mydata, paste0(filename, "_PU.sav"))

# Add report title dynamically
title_var <- paste0("DOL-ILAB SDC - ", filename)
#'---
#'  title: `r title_var`
#'---
